# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/shopping/brand/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/shopping/brand/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Shopping\\Brand\\": "packages/shopping/brand/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Shopping\Brand\Providers\BrandServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Brand'  => Shopping\Brand\Facades\Brand::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Shopping\\BrandTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Shopping\Brand\Providers\BrandServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Shopping\Brand\Providers\BrandServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Shopping\Brand\Providers\BrandServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/brand/{modulename}

**User**

    http://path-to-route-folder/user/brand/{modulename}

**Public**

    http://path-to-route-folder/brands


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/brand/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/brand/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/brand/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/brand/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/brand/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/brand/{modulename}/{slug}
    METHOD: GET